/*
 * Copyright 2009 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gmetrics.result

import org.gmetrics.metric.Metric

/**
 * A NumberMetricResult that aggregates multiple values
 *
 * @author Chris Mair
 * @version $Revision: 24 $ - $Date: 2009-12-10 21:17:05 -0500 (Thu, 10 Dec 2009) $
 */
class AggregateNumberMetricResult implements MetricResult {

    private sum
    private count
    int scale = 1
    final Metric metric

    AggregateNumberMetricResult(Metric metric, Collection children) {
        assert metric != null
        assert children != null
        this.metric = metric
        sum = children.inject(0) { value, child -> value + child.total }
        count = children.inject(0) { value, child -> value + child.count }
    }

    int getCount() {
        return count
    }

    Object getTotal() {
        return sum
    }

    Object getAverage() {
        if(sum && count) {
            def result = sum / count
            return result.setScale(scale, BigDecimal.ROUND_HALF_UP)
        }
        else {
            return 0
        }
    }

    String toString() {
        "AggregateNumberMetricResult[count=$count, total=${getTotal()}, average=${getAverage()}]"
    }

}